@@ -1,21 +1,22 @@
 /*
- * ARP Scan is Copyright (C) 2005-2008 Roy Hills, NTA Monitor Ltd.
+ * ARP Scan is Copyright (C) 2005-2011 Roy Hills, NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This file is part of arp-scan.
+ * 
+ * arp-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: arp-scan.h 13669 2008-07-17 12:01:12Z rsh $
+ * $Id: arp-scan.h 18136 2011-02-25 21:29:45Z rsh $
  *
  * arp-scan.h -- Header file for ARP scanner
  *
@@ -63,10 +64,6 @@
 #include <netdb.h>
 #endif
 
-#ifdef HAVE_SYSLOG_H
-#include <syslog.h>
-#endif
-
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #else
@@ -105,7 +102,27 @@
 #include <regex.h>		/* Posix regular expression functions */
 #endif
 
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef HAVE_PCAP_H
+/*
+ * The pcap.h header file on Apple Mac OS Xcode 2.5 and later includes pcap's
+ * cut-down version of bpf.h, which defines macros that conflict with those in
+ * the full bpf.h. To avoid the conflict, we include net/bpf.h before pcap.h
+ * if compiling under Xcode 2.5 or later. This defines all the required macros
+ * and prevents pcap's cut-down version from defining its own ones.
+ *
+ * 5370 is the value of __APPLE_CC__ for Xcode 2.5 on Tiger with GCC 4.0.1
+ */
+#if defined(__APPLE_CC__) && (__APPLE_CC__ >= 5370)
+#include <net/bpf.h>
+#endif
 #include <pcap.h>
 #endif
 
@@ -125,8 +142,6 @@
 
 #define MAXLINE 255			/* Max line length for input files */
 #define MAX_FRAME 2048			/* Maximum allowed frame size */
-#undef SYSLOG				/* Use syslog if defined */
-#define SYSLOG_FACILITY LOG_USER	/* Syslog facility to use */
 #define REALLOC_COUNT 1000		/* Entries to realloc at once */
 #define DEFAULT_BANDWIDTH 256000	/* Default bandwidth in bits/sec */
 #define PACKET_OVERHEAD 18		/* layer 2 overhead (6+6+2 + 4) */ 
@@ -157,6 +172,9 @@
 #define DEFAULT_ETH_PRO	ETH_P_ARP	/* Default Ethernet protocol */
 #define FRAMING_ETHERNET_II 0		/* Standard Ethernet-II Framing */
 #define FRAMING_LLC_SNAP 1		/* 802.3 with LLC/SNAP */
+#define ARRAY_SIZE(a) (sizeof (a) / sizeof ((a)[0]))
+#define OPT_WRITEPKTTOFILE 256		/* --writepkttofile option */
+#define OPT_READPKTFROMFILE 257		/* --readpktfromfile option */
 
 /* Structures */
 
@@ -205,13 +223,12 @@ void err_sys(const char *, ...);
 void warn_sys(const char *, ...);
 void err_msg(const char *, ...);
 void warn_msg(const char *, ...);
-void info_syslog(const char *, ...);
-void err_print(int, int, const char *, va_list);
-void usage(int);
+void err_print(int, const char *, va_list);
+void usage(int, int);
 void add_host_pattern(const char *, unsigned);
-void add_host(const char *, unsigned);
+void add_host(const char *, unsigned, int);
 int send_packet(link_t *, host_entry *, struct timeval *);
-void recvfrom_wto(int, unsigned char *, int, struct sockaddr *, int);
+void recvfrom_wto(int, int);
 void remove_host(host_entry **);
 void timeval_diff(const struct timeval *, const struct timeval *,
                   struct timeval *);
@@ -249,6 +266,9 @@ void *Malloc(size_t);
 void *Realloc(void *, size_t);
 unsigned long int Strtoul(const char *, int);
 long int Strtol(const char *, int);
+unsigned str_to_bandwidth(const char *);
+unsigned str_to_interval(const char *);
+char *dupstr(const char *);
 /* MT19937 prototypes */
 void init_genrand(unsigned long);
 void init_by_array(unsigned long[], int);
