@@ -1,32 +1,33 @@
 /*
- * The ARP scanner (arp-scan) is Copyright (C) 2005-2008
+ * The ARP scanner (arp-scan) is Copyright (C) 2005-2011
  * Roy Hills, NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This file is part of arp-scan.
+ * 
+ * arp-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: error.c 13669 2008-07-17 12:01:12Z rsh $
+ * $Id: error.c 18078 2011-01-09 10:37:07Z rsh $
  *
  * error.c -- error routines for arp-scan
  *
  * Author:	Roy Hills
  * Date:	1 December 2001
- *
  */
+
 #include "arp-scan.h"
 
-static char rcsid[] = "$Id: error.c 13669 2008-07-17 12:01:12Z rsh $"; /* RCS ID for ident(1) */
+static char rcsid[] = "$Id: error.c 18078 2011-01-09 10:37:07Z rsh $"; /* RCS ID for ident(1) */
 
 int daemon_proc;	/* Non-zero if process is a daemon */
 
@@ -38,7 +39,7 @@ err_sys(const char *fmt,...) {
    va_list ap;
 
    va_start(ap, fmt);
-   err_print(1, 0, fmt, ap);
+   err_print(1, fmt, ap);
    va_end(ap);
    exit(EXIT_FAILURE);
 }
@@ -51,7 +52,7 @@ warn_sys(const char *fmt,...) {
    va_list ap;
 
    va_start(ap, fmt);
-   err_print(1, 0, fmt, ap);
+   err_print(1, fmt, ap);
    va_end(ap);
 }
 
@@ -63,7 +64,7 @@ err_msg(const char *fmt,...) {
    va_list ap;
 
    va_start(ap, fmt);
-   err_print(0, 0, fmt, ap);
+   err_print(0, fmt, ap);
    va_end(ap);
    exit(EXIT_FAILURE);
 }
@@ -76,19 +77,7 @@ warn_msg(const char *fmt,...) {
    va_list ap;
 
    va_start(ap, fmt);
-   err_print(0, 0, fmt, ap);
-   va_end(ap);
-}
-
-/*
- *	Function to handle informational syslog messages
- */
-void
-info_syslog(const char *fmt,...) {
-   va_list ap;
-
-   va_start(ap, fmt);
-   err_print(0, LOG_INFO, fmt, ap);
+   err_print(0, fmt, ap);
    va_end(ap);
 }
 
@@ -97,7 +86,7 @@ info_syslog(const char *fmt,...) {
  *	functions.
  */
 void
-err_print (int errnoflag, int level, const char *fmt, va_list ap) {
+err_print (int errnoflag, const char *fmt, va_list ap) {
    int errno_save;
    size_t n;
    char buf[MAXLINE];
@@ -110,13 +99,9 @@ err_print (int errnoflag, int level, const char *fmt, va_list ap) {
      snprintf(buf+n, MAXLINE-n, ": %s", strerror(errno_save));
    strlcat(buf, "\n", sizeof(buf));
 
-   if (level != 0) {
-      syslog(level, "%s", buf);
-   } else {
-      fflush(stdout);	/* In case stdout and stderr are the same */
-      fputs(buf, stderr);
-      fflush(stderr);
-   }
+   fflush(stdout);	/* In case stdout and stderr are the same */
+   fputs(buf, stderr);
+   fflush(stderr);
 }
 
 void
