@@ -1,22 +1,23 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2008 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2011 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This file is part of arp-scan.
+ * 
+ * arp-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: link-dlpi.c 13669 2008-07-17 12:01:12Z rsh $
+ * $Id: link-dlpi.c 18090 2011-01-31 11:25:04Z rsh $
  *
  * link-dlpi.c -- DLPI link layer send functions for arp-scan
  *
@@ -69,7 +70,7 @@
  * unsigned char for our buffers and so must multiply by four */
 #define MAXDLBUF 8192*4
 
-static char const rcsid[] = "$Id: link-dlpi.c 13669 2008-07-17 12:01:12Z rsh $";   /* RCS ID for ident(1) */
+static char const rcsid[] = "$Id: link-dlpi.c 18090 2011-01-31 11:25:04Z rsh $";   /* RCS ID for ident(1) */
 
 /*
  *	Link layer handle structure for DLPI.
@@ -127,7 +128,7 @@ link_match_ppa(link_t *handle, const char *device) {
 #endif
 
 static int
-dlpi_msg(int fd, union DL_primitives *dlp, int rlen, int flags, int ack,
+dlpi_msg(int fd, union DL_primitives *dlp, int rlen, int flags, unsigned ack,
          int alen, int size) {
 
    struct strbuf ctl;
