@@ -1,25 +1,26 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2008 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2011 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This file is part of arp-scan.
+ * 
+ * arp-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
  * You are encouraged to send comments, improvements or suggestions to
  * me at arp-scan@nta-monitor.com.
  *
- * $Id: utils.c 13669 2008-07-17 12:01:12Z rsh $
+ * $Id: utils.c 18078 2011-01-09 10:37:07Z rsh $
  *
  * Author: Roy Hills
  * Date: 5 April 2004
@@ -29,7 +30,7 @@
 
 #include "arp-scan.h"
 
-static char rcsid[] = "$Id: utils.c 13669 2008-07-17 12:01:12Z rsh $";	/* RCS ID for ident(1) */
+static char rcsid[] = "$Id: utils.c 18078 2011-01-09 10:37:07Z rsh $";	/* RCS ID for ident(1) */
 
 
 /*
@@ -120,7 +121,7 @@ hstr_i(const char *cptr)
  *
  *	The returned pointer points to malloc'ed storage which should be
  *	free'ed by the caller when it's no longer needed.  If the length of
- *	the inputs string is not even, the function will return NULL and
+ *	the input string is not even, the function will return NULL and
  *	set data_len to 0.
  */
 unsigned char *
@@ -172,7 +173,7 @@ make_message(const char *fmt, ...) {
       n = vsnprintf (p, size, fmt, ap);
       va_end(ap);
       /* If that worked, return the string. */
-      if (n > -1 && n < size)
+      if (n > -1 && n < (int) size)
          return p;
       /* Else try again with more space. */
       if (n > -1)    /* glibc 2.1 */
@@ -260,12 +261,12 @@ print_times(void) {
       first_call=0;
       time_first.tv_sec  = time_now.tv_sec;
       time_first.tv_usec = time_now.tv_usec;
-      printf("%lu.%.6lu (0.000000) [0.000000]\n",
+      printf("%lu.%.6lu (0.000000) [0.000000]\t",
              (unsigned long)time_now.tv_sec, (unsigned long)time_now.tv_usec);
    } else {
       timeval_diff(&time_now, &time_last, &time_delta1);
       timeval_diff(&time_now, &time_first, &time_delta2);
-      printf("%lu.%.6lu (%lu.%.6lu) [%lu.%.6lu]\n",
+      printf("%lu.%.6lu (%lu.%.6lu) [%lu.%.6lu]\t",
              (unsigned long)time_now.tv_sec,
              (unsigned long)time_now.tv_usec,
              (unsigned long)time_delta1.tv_sec,
@@ -321,6 +322,122 @@ get_ether_addr(const char *address_string, unsigned char *ether_addr) {
    return 0;
 }
 
+/*
+ *	str_to_bandwidth -- Convert a bandwidth string to unsigned integer
+ *
+ *	Inputs:
+ *
+ *	bandwidth_string	The bandwidth string to convert
+ *
+ *	Returns:
+ *
+ *	The bandwidth in bits per second as an unsigned integer
+ */
+unsigned
+str_to_bandwidth(const char *bandwidth_string) {
+   char *bandwidth_str;
+   size_t bandwidth_len;
+   unsigned value;
+   int multiplier=1;
+   int end_char;
+
+   bandwidth_str=dupstr(bandwidth_string);	/* Writable copy */
+   bandwidth_len=strlen(bandwidth_str);
+   end_char = bandwidth_str[bandwidth_len-1];
+   if (!isdigit(end_char)) {	/* End character is not a digit */
+      bandwidth_str[bandwidth_len-1] = '\0';	/* Remove last character */
+      switch (end_char) {
+         case 'M':
+         case 'm':
+            multiplier = 1000000;
+            break;
+         case 'K':
+         case 'k':
+            multiplier = 1000;
+            break;
+         default:
+            err_msg("ERROR: Unknown bandwidth multiplier character: \"%c\"",
+                    end_char);
+            break;
+      }
+   }
+   value=Strtoul(bandwidth_str, 10);
+   free(bandwidth_str);
+   return multiplier * value;
+}
+
+/*
+ *	str_to_interval -- Convert an interval string to unsigned integer
+ *
+ *	Inputs:
+ *
+ *	interval_string		The interval string to convert
+ *
+ *	Returns:
+ *
+ *	The interval in microsecons as an unsigned integer
+ */
+unsigned
+str_to_interval(const char *interval_string) {
+   char *interval_str;
+   size_t interval_len;
+   unsigned value;
+   int multiplier=1000;
+   int end_char;
+
+   interval_str=dupstr(interval_string);	/* Writable copy */
+   interval_len=strlen(interval_str);
+   end_char = interval_str[interval_len-1];
+   if (!isdigit(end_char)) {	/* End character is not a digit */
+      interval_str[interval_len-1] = '\0';	/* Remove last character */
+      switch (end_char) {
+         case 'U':
+         case 'u':
+            multiplier = 1;
+            break;
+         case 'S':
+         case 's':
+            multiplier = 1000000;
+            break;
+         default:
+            err_msg("ERROR: Unknown interval multiplier character: \"%c\"",
+                    end_char);
+            break;
+      }
+   }
+   value=Strtoul(interval_str, 10);
+   free(interval_str);
+   return multiplier * value;
+}
+
+/*
+ *	dupstr -- duplicate a string
+ *
+ *	Inputs:
+ *
+ *	str	The string to duplcate
+ *
+ *	Returns:
+ *
+ *	A pointer to the duplicate string.
+ *
+ *	This is a replacement for the common but non-standard "strdup"
+ *	function.
+ *
+ *	The returned pointer points to Malloc'ed memory, which must be
+ *	free'ed by the caller.
+ */
+char *
+dupstr(const char *str) {
+   char *cp;
+   size_t len;
+
+   len = strlen(str) + 1;	/* Allow space for terminating NULL */
+   cp = Malloc(len);
+   strlcpy(cp, str, len);
+   return cp;
+}
+
 void utils_use_rcsid(void) {
    fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
 }
