@@ -1,22 +1,23 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2008 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2011 Roy Hills,
  * NTA Monitor Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This file is part of arp-scan.
+ * 
+ * arp-scan is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: wrappers.c 13669 2008-07-17 12:01:12Z rsh $
+ * $Id: wrappers.c 18078 2011-01-09 10:37:07Z rsh $
  *
  * Author: Roy Hills
  * Date: 8 November 2003
@@ -35,7 +36,7 @@
 
 #include "arp-scan.h"
 
-static char rcsid[] = "$Id: wrappers.c 13669 2008-07-17 12:01:12Z rsh $";	/* RCS ID for ident(1) */
+static char rcsid[] = "$Id: wrappers.c 18078 2011-01-09 10:37:07Z rsh $";	/* RCS ID for ident(1) */
 
 /*
  * We omit the timezone arg from this wrapper since it's obsolete and we never
@@ -79,7 +80,9 @@ unsigned long int Strtoul(const char *nptr, int base) {
    unsigned long int result;
 
    result=strtoul(nptr, &endptr, base);
-   if (endptr == nptr)  /* No digits converted */
+   if (endptr == nptr)	/* No digits converted */
+      err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
+   if (*endptr != '\0' && !isspace((unsigned char)*endptr))
       err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
 
    return result;
@@ -90,7 +93,9 @@ long int Strtol(const char *nptr, int base) {
    long int result;
 
    result=strtol(nptr, &endptr, base);
-   if (endptr == nptr)  /* No digits converted */
+   if (endptr == nptr)	/* No digits converted */
+      err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
+   if (*endptr != '\0' && !isspace((unsigned char)*endptr))
       err_msg("ERROR: \"%s\" is not a valid numeric value", nptr);
 
    return result;
